@@ -5,7 +5,7 @@ OC.L10N.register(
     "Details" : "详情",
     "All contacts" : "全部联系人",
     "_Imported %n contact_::_Imported %n contacts_" : ["已导入 %n 位联系人"],
-    "_Imported %n contact (skipped %d)_::_Imported %n contacts (skipped %d)_" : ["已导入 %n 位联系人（跳过 %d 位）"],
+    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["（已跳过 %n 个联系人）"],
     "Contacts" : "联系人",
     "A contacts app for Nextcloud" : "适用于 Nextcloud 的联系人应用",
     "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud通讯录应用程序是Nextcloud的CardDAV服务器用户界面。您可以轻松使用您的Nextcloud同步各设备上的联系人，并在线上编辑。\n\n* 🚀 **与其他Nextcloud应用程序整合！** 目前有邮件和日历，还会有更多。\n* 🎉 **不会忘记生日！** 您可以将生日与其他重复的活动与您的Nextcloud日历同步。\n* 👥 **分享通讯录！** 您想与您的朋友或同事分享您的联系人吗？没问题！\n* 🙈 **我们不是在重复造轮子！** 基于出色且开源的SabreDAV库。",
@@ -75,7 +75,6 @@ OC.L10N.register(
     "No users or groups" : "无用户或群组",
     "Unable to delete the share" : "无法删除共享",
     "Unable to change permissions" : "无法更改权限",
-    "can edit" : "可编辑",
     "Choose a vCard file to import" : "选择要导入的 vCard（电子名片） 文件",
     "Import into the {addressbookName} address book" : "导入 {addressbookName} 通讯录",
     "Select local file" : "选择本地文件",
@@ -105,9 +104,10 @@ OC.L10N.register(
     "Close" : "关闭",
     "There is no description for this team" : "此团队没有描述",
     "Enter a description for the team" : "输入团队的描述",
-    "Team folder" : "团队文件夹",
-    "New Team folder" : "新团队文件夹",
+    "Folder" : "文件夹",
+    "New folder" : "新文件夹",
     "Folder name" : "文件夹名称",
+    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "这将创建一个与团队共享的常规文件夹。要创建团队文件夹，请联系您的 {productName} 管理员",
     "Talk conversation" : "Talk 对话",
     "New Talk conversation" : "新 Talk 对话",
     "Conversation name" : "对话名称",
@@ -383,6 +383,7 @@ OC.L10N.register(
     "General settings" : "一般设置",
     "(refreshed once per week)" : "（每周刷新）",
     "{addressbookname} (Disabled)" : "{addressbookname}（已禁用）",
+    "can edit" : "可编辑",
     "Unique password …" : "唯一密码…",
     "Search contacts …" : "搜索联系人…",
     "Invite members to team" : "邀请成员加入团队",
