@@ -75,7 +75,7 @@ OC.L10N.register(
     "No users or groups" : "沒有用戶或群組",
     "Unable to delete the share" : "無法刪除這個分享",
     "Unable to change permissions" : "無法變更權限",
-    "can edit" : "允許編輯",
+    "can create and edit" : "可以創建和編輯",
     "Choose a vCard file to import" : "選取要導入的 vCard 檔案",
     "Import into the {addressbookName} address book" : "導入至 {addressbookName} 通訊錄",
     "Select local file" : "選擇本機檔案",
@@ -305,6 +305,8 @@ OC.L10N.register(
     "Members can also invite" : "會員也可以邀請",
     "Membership" : "成員資格",
     "Prevent teams from being a member of another team" : "防止團隊成為另一個團隊的成員",
+    "Federation" : "聯盟",
+    "Allow federated members" : "允許聯合成員",
     "Privacy" : "隱私",
     "Visible to everyone" : "所有人都看得到",
     "users" : "用戶",
@@ -384,12 +386,12 @@ OC.L10N.register(
     "General settings" : "一般設定",
     "(refreshed once per week)" : "（每週重新整理一次）",
     "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
+    "can edit" : "允許編輯",
     "Unique password …" : "獨一無二的密碼 ...",
     "Search contacts …" : "搜尋聯絡人…",
     "Invite members to team" : "邀請成員加入團隊",
     "Loading members list …" : "正在加載成員清單 …",
     "Add to {circle}" : "添加到 {circle}",
-    "Select chart …" : "選擇圖表 ...",
-    "_Imported %n contact (skipped %d)_::_Imported %n contacts (skipped %d)_" : ["已導入 %n 個聯絡人（略過 %d 個）"]
+    "Select chart …" : "選擇圖表 ..."
 },
 "nplurals=1; plural=0;");
