@@ -75,7 +75,6 @@ OC.L10N.register(
     "No users or groups" : "沒有使用者或群組",
     "Unable to delete the share" : "無法刪除這個分享",
     "Unable to change permissions" : "無法變更權限",
-    "can edit" : "允許編輯",
     "Choose a vCard file to import" : "選取要匯入的 vCard 檔案",
     "Import into the {addressbookName} address book" : "匯入至 {addressbookName} 通訊錄",
     "Select local file" : "選取本機檔案",
@@ -384,12 +383,12 @@ OC.L10N.register(
     "General settings" : "一般設定",
     "(refreshed once per week)" : "（每週重新整理一次）",
     "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
+    "can edit" : "允許編輯",
     "Unique password …" : "獨一無二的密碼……",
     "Search contacts …" : "搜尋聯絡人……",
     "Invite members to team" : "邀請成員加入團隊",
     "Loading members list …" : "正在載入成員清單……",
     "Add to {circle}" : "新增至 {circle}",
-    "Select chart …" : "選取圖表……",
-    "_Imported %n contact (skipped %d)_::_Imported %n contacts (skipped %d)_" : ["已匯入 %n 個聯絡人（略過 %d 個）"]
+    "Select chart …" : "選取圖表……"
 },
 "nplurals=1; plural=0;");
